package com.chelvc.framework.base.config;

import java.util.List;
import java.util.Map;
import java.util.function.Predicate;

import com.chelvc.framework.base.context.ApplicationContextHolder;
import com.chelvc.framework.common.util.StringUtils;
import com.google.common.collect.Maps;
import org.springframework.boot.autoconfigure.web.servlet.WebMvcRegistrations;
import org.springframework.core.io.Resource;
import org.springframework.web.servlet.mvc.method.annotation.RequestMappingHandlerMapping;

/**
 * 多服务MVC配置
 *
 * @author Woody
 * @date 2024/1/30
 */
public class MultiserverMvcConfigurer implements WebMvcRegistrations {
    @Override
    public RequestMappingHandlerMapping getRequestMappingHandlerMapping() {
        List<Resource> resources = ApplicationContextHolder.getApplicationResources();
        Map<String, Predicate<Class<?>>> prefixes = Maps.newHashMapWithExpectedSize(resources.size());
        for (Resource resource : resources) {
            String server = ApplicationContextHolder.getApplicationName(resource);
            if (StringUtils.notEmpty(server)) {
                prefixes.put(server, clazz -> ApplicationContextHolder.isResourceClass(resource, clazz));
            }
        }
        RequestMappingHandlerMapping mapping = new RequestMappingHandlerMapping();
        mapping.setPathPrefixes(prefixes);
        return mapping;
    }
}