package com.chelvc.framework.base.context;

import com.chelvc.framework.common.model.Enumerable;
import com.chelvc.framework.common.util.DateUtils;
import lombok.Getter;

/**
 * 使用类别枚举
 *
 * @author Woody
 * @date 2023/9/10
 */
@Getter
public enum Using implements Enumerable {
    /**
     * 历史首次
     */
    INITIAL("历史首次"),

    /**
     * 当日首次
     */
    DAILY("当日首次"),

    /**
     * 当前首次
     */
    NEWLY("当前首次"),

    /**
     * 普通请求
     */
    NORMAL("普通请求");

    /**
     * 默认使用刷新时间间隔（15分钟）
     */
    public static final long DEFAULT_NEWLY_INTERVAL = 15 * 60 * 1000;

    /**
     * 类别描述
     */
    private final String description;

    Using(String description) {
        this.description = description;
    }

    /**
     * 根据上次使用时间及注册时间计算使用类型
     *
     * @param latest   上次使用时间戳
     * @param creating 用户创建时间戳
     * @return 使用类型枚举
     */
    public static Using from(Long latest, Long creating) {
        return from(latest, creating, DEFAULT_NEWLY_INTERVAL);
    }

    /**
     * 根据上次使用时间及注册时间计算使用类型
     *
     * @param latest   上次使用时间戳
     * @param creating 用户创建时间戳
     * @param interval 使用刷新时间间隔（毫秒）
     * @return 使用类型枚举
     */
    public static Using from(Long latest, Long creating, long interval) {
        if (latest == null) {
            return creating == null || creating < DateUtils.today().getTime() ? DAILY : INITIAL;
        }
        return System.currentTimeMillis() - latest > interval ? NEWLY : NORMAL;
    }
}
