package com.chelvc.framework.common.jackson;

import java.io.IOException;

import com.chelvc.framework.common.model.Enumerable;
import com.fasterxml.jackson.core.JsonGenerator;
import com.fasterxml.jackson.databind.SerializerProvider;
import com.fasterxml.jackson.databind.ser.std.StdSerializer;
import com.google.common.collect.ImmutableMap;

/**
 * JSON枚举序列化处理器
 *
 * @author Woody
 * @date 2024/1/30
 */
public class JacksonEnumerateSerializer extends StdSerializer<Object> {
    /**
     * 编号属性名称
     */
    public static final String CODE = "code";

    /**
     * 描述属性名称
     */
    public static final String DESCRIPTION = "description";

    public JacksonEnumerateSerializer() {
        super(Object.class);
    }

    @Override
    public void serialize(Object value, JsonGenerator generator, SerializerProvider provider) throws IOException {
        if (value instanceof Enumerable) {
            Enumerable enumerable = (Enumerable) value;
            generator.writeObject(ImmutableMap.of(
                    CODE, String.valueOf(enumerable.getCode()),
                    DESCRIPTION, String.valueOf(enumerable.getDescription())
            ));
        } else if (value instanceof Enum) {
            Enum<?> enumerable = (Enum<?>) value;
            generator.writeObject(ImmutableMap.of(CODE, enumerable.name(), DESCRIPTION, enumerable.name()));
        } else {
            generator.writeObject(value);
        }
    }
}
