package com.chelvc.framework.database.context;

import java.io.Serializable;
import java.util.Collections;
import java.util.Map;
import java.util.stream.Collectors;

import com.baomidou.mybatisplus.core.metadata.TableInfo;
import com.chelvc.framework.common.util.ObjectUtils;
import lombok.Getter;
import lombok.NonNull;

/**
 * 表上下文对象
 *
 * @author Woody
 * @date 2025/1/5
 */
@Getter
public class TableContext implements Serializable {
    private final TableInfo table;
    private final Map<String, TableFieldContext> fields;

    public TableContext(@NonNull TableInfo table) {
        this.table = table;
        if (ObjectUtils.isEmpty(table.getFieldList())) {
            this.fields = Collections.emptyMap();
        } else {
            this.fields = Collections.unmodifiableMap(table.getFieldList().stream().collect(Collectors.toMap(
                    field -> DatabaseContextHolder.unquote(field.getColumn()), TableFieldContext::new
            )));
        }
    }

    /**
     * 获取数据模型
     *
     * @return 模型对象
     */
    public Class<?> getModel() {
        return this.table.getEntityType();
    }

    /**
     * 获取表字段上下文
     *
     * @param field 字段名称
     * @return 表字段上下文
     */
    public TableFieldContext getFieldContext(@NonNull String field) {
        return this.fields.get(DatabaseContextHolder.unquote(field));
    }
}
