package com.chelvc.framework.email.config;

import java.util.Properties;
import javax.mail.Authenticator;
import javax.mail.PasswordAuthentication;
import javax.mail.Session;

import com.chelvc.framework.common.util.StringUtils;
import com.chelvc.framework.email.DefaultEmailHandler;
import com.chelvc.framework.email.EmailHandler;
import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

/**
 * 邮件配置
 *
 * @author Woody
 * @date 2024/1/30
 */
@Configuration
public class EmailConfigurer {
    @Bean
    @ConditionalOnMissingBean(Session.class)
    public Session session(EmailProperties properties) {
        Properties config = new Properties();
        config.setProperty("mail.transport.protocol", properties.getProtocol());
        config.setProperty(String.format("mail.%s.port", properties.getProtocol()),
                String.valueOf(properties.getPort()));
        config.setProperty(String.format("mail.%s.host", properties.getProtocol()), properties.getHost());
        config.setProperty(String.format("mail.%s.auth", properties.getProtocol()), StringUtils.TRUE);
        if (properties.isEncrypted()) {
            config.setProperty(String.format("mail.%s.ssl.enable", properties.getProtocol()), StringUtils.TRUE);
            config.setProperty(String.format("mail.%s.ssl.protocols", properties.getProtocol()), "TLSv1.2");
            config.setProperty(String.format("mail.%s.socketFactory.port", properties.getProtocol()),
                    String.valueOf(properties.getPort()));
            config.setProperty(String.format("mail.%s.socketFactory.class", properties.getProtocol()),
                    "javax.net.ssl.SSLSocketFactory");
        }
        return Session.getInstance(config, new Authenticator() {
            @Override
            protected PasswordAuthentication getPasswordAuthentication() {
                return new PasswordAuthentication(properties.getUsername(), properties.getPassword());
            }
        });
    }

    @Bean
    @ConditionalOnMissingBean(EmailHandler.class)
    public EmailHandler emailHandler(Session session, EmailProperties properties) {
        return new DefaultEmailHandler(session, properties);
    }
}
