package com.chelvc.framework.group;

import java.util.Collection;
import java.util.Map;

import com.chelvc.framework.common.model.Caps;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

/**
 * 场景分组客户端
 *
 * @author Woody
 * @date 2024/12/5
 */
@FeignClient(value = "${group.store-server}")
public interface GroupClient {
    /**
     * 获取分组标识
     *
     * @param scene 场景标识
     * @return 分组标识
     */
    @GetMapping("/grouping/{scene}")
    Caps get(@PathVariable("scene") String scene);

    /**
     * 批量获取分组标识
     *
     * @param scenes 分组场景集合
     * @return 分组场景/标识映射表
     */
    @GetMapping("/grouping")
    Map<String, Caps> get(@RequestParam("scenes") Collection<String> scenes);

    /**
     * 设置分组标识，如果分组不存在则设置分组，否则忽略
     *
     * @param scene 分组场景
     * @param group 分组标识
     * @return 分组标识
     */
    @PostMapping("/grouping/{scene}/{group}")
    Caps set(@PathVariable("scene") String scene, @PathVariable("group") Caps group);

    /**
     * 批量设置分组标识，如果分组不存在则设置分组，否则忽略
     *
     * @param groups 分组场景/标识映射表
     * @return 分组场景/标识映射表
     */
    @PostMapping("/grouping")
    Map<String, Caps> set(@RequestBody Map<String, Caps> groups);
}
