package com.chelvc.framework.kafka.config;

import java.nio.charset.StandardCharsets;
import java.util.Collections;
import java.util.List;

import com.chelvc.framework.common.util.JacksonUtils;
import com.chelvc.framework.kafka.fallback.KafkaFallbackPolicy;
import com.chelvc.framework.kafka.interceptor.KafkaSessionInterceptor;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.ToString;
import org.apache.kafka.clients.producer.ProducerConfig;
import org.apache.kafka.common.serialization.Serializer;
import org.apache.kafka.common.serialization.StringDeserializer;
import org.apache.kafka.common.serialization.StringSerializer;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.Primary;

/**
 * Kafka配置属性
 *
 * @author Woody
 * @date 2024/1/30
 */
@Data
@Primary
@Configuration
@ToString(callSuper = true)
@EqualsAndHashCode(callSuper = true)
public class KafkaProperties extends org.springframework.boot.autoconfigure.kafka.KafkaProperties {
    /**
     * Jackson序列化处理器
     */
    public static class JacksonSerializer implements Serializer<Object> {
        @Override
        public byte[] serialize(String topic, Object payload) {
            return payload == null ? null : JacksonUtils.serialize(payload).getBytes(StandardCharsets.UTF_8);
        }
    }

    /**
     * 命名空间
     */
    private String namespace;

    /**
     * 降级策略列表
     */
    private List<KafkaFallbackPolicy> fallbacks = Collections.emptyList();

    {
        // 初始化生产者默认配置
        this.getProducer().setAcks("1");
        this.getProducer().setKeySerializer(StringSerializer.class);
        this.getProducer().setValueSerializer(JacksonSerializer.class);
        this.getProducer().getProperties().put(
                ProducerConfig.INTERCEPTOR_CLASSES_CONFIG, KafkaSessionInterceptor.class.getName()
        );

        // 初始化消费者默认配置
        this.getConsumer().setEnableAutoCommit(true);
        this.getConsumer().setAutoOffsetReset("latest");
        this.getConsumer().setKeyDeserializer(StringDeserializer.class);
        this.getConsumer().setValueDeserializer(StringDeserializer.class);
    }
}
