package com.chelvc.framework.rocketmq.producer;

import java.util.Collections;
import java.util.Map;
import java.util.stream.Collectors;

import com.chelvc.framework.common.util.JacksonUtils;
import com.chelvc.framework.common.util.ObjectUtils;
import com.chelvc.framework.rocketmq.context.RocketMQContextHolder;
import lombok.NonNull;
import lombok.extern.slf4j.Slf4j;
import org.apache.rocketmq.client.apis.message.MessageView;
import org.apache.rocketmq.client.apis.producer.TransactionChecker;
import org.apache.rocketmq.client.apis.producer.TransactionResolution;
import org.springframework.context.ApplicationContext;

/**
 * RocketMQ事务本地检测公共处理器实现
 *
 * @author Woody
 * @date 2024/10/29
 */
@Slf4j
public class CommonTransactionChecker implements TransactionChecker {
    private final Map<String, TransactionMessageChecker<?>> checkers;

    @SuppressWarnings({"unchecked", "rawtypes"})
    public CommonTransactionChecker(@NonNull ApplicationContext applicationContext) {
        Map<String, TransactionMessageChecker> checkers =
                applicationContext.getBeansOfType(TransactionMessageChecker.class);
        this.checkers = ObjectUtils.isEmpty(checkers) ? Collections.emptyMap() :
                checkers.values().stream().collect(Collectors.toMap(TransactionMessageChecker::topic, c -> c));
    }

    @Override
    @SuppressWarnings({"unchecked", "rawtypes"})
    public TransactionResolution check(MessageView message) {
        String body = RocketMQContextHolder.body(message);
        String topic = RocketMQContextHolder.topic(message);
        TransactionMessageChecker checker = this.checkers.get(topic);
        if (checker == null) {
            log.error("Transaction message checker is missing: {}, {}", topic, body);
            return TransactionResolution.UNKNOWN;
        }
        return checker.check(JacksonUtils.deserialize(body, checker.model()));
    }
}
