package com.chelvc.framework.upload.support;

import java.io.File;
import java.io.IOException;
import java.io.InputStream;

import com.chelvc.framework.base.util.HttpUtils;
import com.chelvc.framework.common.util.AssertUtils;
import com.chelvc.framework.common.util.FileUtils;
import com.chelvc.framework.upload.UploadHandler;
import com.chelvc.framework.upload.config.UploadProperties;
import lombok.NonNull;

/**
 * 文件上传默认实现
 *
 * @author Woody
 * @date 2024/1/30
 */
public class DefaultUploadHandler implements UploadHandler {
    private final String domain;
    private final String directory;

    public DefaultUploadHandler(@NonNull UploadProperties properties) {
        this.domain = AssertUtils.nonempty(properties.getDomain(), () -> "Local upload access domain is missing");
        this.directory = AssertUtils.nonempty(properties.getDirectory(), () -> "Local upload directory is missing");
    }

    @Override
    public void refreshContentDeliveryNetwork(String... urls) {
        throw new UnsupportedOperationException();
    }

    @Override
    public String upload(@NonNull File file, @NonNull String filename) throws IOException {
        FileUtils.write(new File(this.directory, filename), file);
        return HttpUtils.url(this.domain, filename);
    }

    @Override
    public String upload(@NonNull InputStream stream, @NonNull String filename) throws IOException {
        return this.upload(stream, filename, stream.available());
    }

    @Override
    public String upload(@NonNull InputStream stream, @NonNull String filename, long length) throws IOException {
        FileUtils.write(new File(this.directory, filename), stream);
        return HttpUtils.url(this.domain, filename);
    }
}
